<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="341"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Vásárold meg az Ultimate verziót a fejlesztés támogatásához</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="341"/>
        <source>Register your key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="440"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>Fájl %1/%2, méret: %3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="674"/>
        <source>Copy list</source>
        <translation>Lista másolása</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="676"/>
        <source>Move list</source>
        <translation>Lista mozgatása</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1117"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Ne zárja be, ha hiba történik</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1118"/>
        <source>Never close</source>
        <translation>Sose zárja be</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1119"/>
        <source>Always close</source>
        <translation>Mindig zárja be</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1121"/>
        <source>File Name, 0KB</source>
        <translation>Fájlnév, 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1395"/>
        <location filename="../../interface.cpp" line="1407"/>
        <location filename="../../interface.cpp" line="1419"/>
        <source>Select a color</source>
        <translation>Válassz egy színt</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1494"/>
        <location filename="../../interface.cpp" line="1498"/>
        <location filename="../../interface.cpp" line="1500"/>
        <source>%1 %2% of %3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="294"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Ne zárja be, ha hiba történik</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="295"/>
        <source>Never close</source>
        <translation>Sose zárja be</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="296"/>
        <source>Always close</source>
        <translation>Mindig zárja be</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="510"/>
        <location filename="../../ThemesFactory.cpp" line="525"/>
        <location filename="../../ThemesFactory.cpp" line="540"/>
        <source>Select a color</source>
        <translation>Válassz egy színt</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="44"/>
        <source>From:</source>
        <translation>Forrás:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="74"/>
        <source>To:</source>
        <translation>Cél:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="235"/>
        <source>&amp;More</source>
        <translation>&amp;Több</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="255"/>
        <source>&amp;Pause</source>
        <translation>&amp;Szünet</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="269"/>
        <source>&amp;Skip</source>
        <translation>&amp;Kihagy</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="280"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Mégse</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="338"/>
        <source>Transfer list</source>
        <translation>Átviteli lista</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="630"/>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="637"/>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="750"/>
        <source>Interface</source>
        <translation>Kezelőfelület</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="361"/>
        <source>Move the selected items to the top</source>
        <translation>Kijelölések elemek mozgatása legfelülre</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="127"/>
        <source>Close on transfer completion</source>
        <translation>Átvitel végeztével zárja be</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="295"/>
        <source>Limit copy speed to:</source>
        <translation>Másolási sebesség korlátozása:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="387"/>
        <source>Move up the selected items</source>
        <translation>Kijelölt elemek mozgatása fel</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="413"/>
        <source>Move down the selected items</source>
        <translation>Kijelölt elemek mozgatása le</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="439"/>
        <source>Move the selected items to the bottom</source>
        <translation>Kijelölések elemek mozgatása legalulra</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="465"/>
        <source>Add file/folder</source>
        <translation>Fájl/mappa hozzáadása</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="494"/>
        <source>Delete the selected items</source>
        <translation>Kijelölt elemek törlése</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="520"/>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="549"/>
        <source>Export the transfer list</source>
        <translation>Átviteli lista exportálása</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="575"/>
        <source>Import the transfer list</source>
        <translation>Átviteli lista importálása</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="672"/>
        <location filename="../../interface.ui" line="741"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="692"/>
        <source>Export the errors into transfer list</source>
        <translation>Hibák exportálása az átviteli listába</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="731"/>
        <source>Source</source>
        <translation>Forrás</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="736"/>
        <source>Destination</source>
        <translation>Cél</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="796"/>
        <source>Add file</source>
        <translation>Fájl hozzáadása</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="805"/>
        <source>Add folder</source>
        <translation>Mappa hozzáadása</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="814"/>
        <source>Move file(s)</source>
        <translation>Fájl(ok) mozgatása</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="823"/>
        <source>Move folder</source>
        <translation>Mappa mozgatása</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="832"/>
        <source>Copy file(s)</source>
        <translation>Fájl(ok) másolása</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="841"/>
        <source>Copy folder</source>
        <translation>Mappa másolása</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="402"/>
        <source>Show dual progression</source>
        <translation>Páros folyamat mutatása</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="219"/>
        <source>Show speed as main information</source>
        <translation>Sebesség mutatása, mint fő információ</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>Használ</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="173"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Indítás a &quot;több gomb&quot; lenyomásával</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="67"/>
        <source>Minimize on close to systray</source>
        <translation>Bezáráskor minimalizálás a tálcára</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="96"/>
        <source>At the end of the copy</source>
        <translation>A másolás befejezésekor</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="103"/>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Limit copy speed to</source>
        <translation>Másolási sebesség korlátozása</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="53"/>
        <source>Start minimized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="213"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="269"/>
        <source>Click to edit the color</source>
        <translation>Kattints a szín szerkesztéséhez</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="147"/>
        <source> KB/s</source>
        <translation> KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="190"/>
        <source>Save position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="251"/>
        <source>Display</source>
        <translation>Megjelenítés</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="368"/>
        <source>Speed with progress bar</source>
        <translation>Sebesség folyamatsávval</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="378"/>
        <source>Progression color</source>
        <translation>Folyamat színe</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="388"/>
        <source>Show progression in the title</source>
        <translation>Folyamat mutatása a címsorban</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="395"/>
        <source>General margin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="425"/>
        <source>General spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="183"/>
        <source>Always on top</source>
        <translation>Mindig legfelül</translation>
    </message>
</context>
</TS>
